=======================================================
trame-tauri
=======================================================

Widgets/utils library to help with Tauri integration in trame.

Usage
-----------------------------------------------------------

More to come, but we currently provide our `./examples/*` directory to capture mainstream use cases.

Development
-----------------------------------------------------------

Build and install the Vue components

.. code-block:: console

    cd vue-components
    npm i
    npm run build
    cd -

Install the application

.. code-block:: console

    pip install -e .


License
-----------------------------------------------------------

trame-tauri is made available under the apache License. For more details, see `LICENSE <https://github.com/Kitware/trame-tauri/blob/master/LICENSE>`_
This license has been chosen to match the one use by `Tauri <https://github.com/tauri-apps/tauri/blob/dev/LICENSE_APACHE-2.0>`_ even is we are not importing Tauri into this library directly.


Community
-----------------------------------------------------------

`Trame <https://kitware.github.io/trame/>`_ | `Discussions <https://github.com/Kitware/trame/discussions>`_ | `Issues <https://github.com/Kitware/trame/issues>`_ | `RoadMap <https://github.com/Kitware/trame/projects/1>`_ | `Contact Us <https://www.kitware.com/contact-us/>`_

.. image:: https://zenodo.org/badge/410108340.svg
    :target: https://zenodo.org/badge/latestdoi/410108340


Enjoying trame?
-----------------------------------------------------------

Share your experience `with a testimonial <https://github.com/Kitware/trame/issues/18>`_ or `with a brand approval <https://github.com/Kitware/trame/issues/19>`_.
